==> lxqt-l10n-0.11.2.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="72"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="72"/>
        <source>Hibernate failed.</source>
        <translation>Échec de la mise en hibernation.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Notifications de repli</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="114"/>
        <source>Hibernate</source>
        <translation>Hiberner</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="121"/>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="128"/>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="135"/>
        <source>Shutdown</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="142"/>
        <source>Logout</source>
        <translation>Se déconnecter</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="154"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspendre la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="155"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Voulez-vous vraiment suspendre votre ordinateur?&lt;p&gt;Votre ordinateur consommera un peu d&apos;énergie. L&apos;état du système ne sera pas préservé si l&apos;énergie est perdue.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="164"/>
        <source>LXQt Session Hibernate</source>
        <translation>Mettre la session LXQt en hibernation</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="165"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Voulez-vous vraiment mettre votre ordinateur en hibernation?&lt;p&gt;Votre ordinateur consommera un peu d&apos;énergie. L&apos;état du système sera préservé si l&apos;énergie est perdue.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="174"/>
        <source>LXQt Session Reboot</source>
        <translation>Redémarrer la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="175"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment redémarrer votre ordinateur? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="184"/>
        <source>LXQt Session Shutdown</source>
        <translation>Éteindre la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="185"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment éteindre votre ordinateur? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="194"/>
        <source>LXQt Session Logout</source>
        <translation>Se déconnecter de la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="195"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment vous déconnecter? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="203"/>
        <location filename="../../lxqtpowermanager.cpp" line="208"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="203"/>
        <source>Hibernate failed.</source>
        <translation>Échec de la mise en hibernation.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="208"/>
        <source>Suspend failed.</source>
        <translation>Échec de la suspension.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="235"/>
        <source>Lock Screen</source>
        <translation>Verrouiller l&apos;écran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Erreur de l&apos;économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="161"/>
        <location filename="../../lxqtscreensaver.cpp" line="167"/>
        <location filename="../../lxqtscreensaver.cpp" line="174"/>
        <source>Screen Saver Activation Error</source>
        <translation>Erreur lors de la mise en veille</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Echec de démarrage de l&apos;économiseur d&apos;écran. Erreur inconnue - retour d&apos;une valeur non documentée de l&apos;économiseur xdg : %1.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. Les arguments de xdg-screensaver contiennent des erreurs de syntaxe.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. Assurez-vous que screensaver est  installé et actif.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. L&apos;action &apos;activate&apos; a échoué. Assurez-vous que screensaver est  installé et actif.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/liblxqt/liblxqt_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Échec de la mise en hibernation.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Notifications de repli</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Hiberner</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Se déconnecter</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspendre la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Voulez-vous vraiment suspendre votre ordinateur?&lt;p&gt;Votre ordinateur consommera un peu d&apos;énergie. L&apos;état du système ne sera pas préservé si l&apos;énergie est perdue.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Mettre la session LXQt en hibernation</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Voulez-vous vraiment mettre votre ordinateur en hibernation?&lt;p&gt;Votre ordinateur consommera un peu d&apos;énergie. L&apos;état du système sera préservé si l&apos;énergie est perdue.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Redémarrer la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment redémarrer votre ordinateur? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Éteindre la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment éteindre votre ordinateur? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Se déconnecter de la session LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Voulez-vous vraiment vous déconnecter? Tout travail non sauvegardé sera perdu...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Échec de la mise en hibernation.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Échec de la suspension.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Verrouiller l&apos;écran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Erreur de l&apos;économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Erreur lors de la mise en veille</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Echec de démarrage de l&apos;économiseur d&apos;écran. Erreur inconnue - retour d&apos;une valeur non documentée de l&apos;économiseur xdg : %1.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. Les arguments de xdg-screensaver contiennent des erreurs de syntaxe.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. Assurez-vous que screensaver est  installé et actif.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Une erreur est survenue lors du démarrage de l&apos;écran de veille. L&apos;action &apos;activate&apos; a échoué. Assurez-vous que screensaver est  installé et actif.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>L&apos;interface QDBus est invalide</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Erreur du gestionnaire d&apos;énergie de LXQt (appel de D-Bus)</translation>
    </message>
</context>
</TS>
